@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2014-2015 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 #include <config.h>
@@ -152,41 +138,20 @@ asb_plugin_process_filename (AsbPlugin *plugin,
 	/* fix up various components as required */
 	if (asb_context_get_flag (plugin->ctx, ASB_CONTEXT_FLAG_ADD_DEFAULT_ICONS)) {
 
-		/* add icon for firmware */
-		if (as_app_get_kind (AS_APP (app)) == AS_APP_KIND_FIRMWARE) {
-			g_autoptr(AsIcon) icon = NULL;
-			icon = as_icon_new ();
-			as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
-			as_icon_set_name (icon, "application-x-executable");
-			as_app_add_icon (AS_APP (app), icon);
-		}
-
 		/* fix up input methods */
 		if (as_app_get_kind (AS_APP (app)) == AS_APP_KIND_INPUT_METHOD) {
-			g_autoptr(AsIcon) icon = NULL;
-			icon = as_icon_new ();
-			as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
-			as_icon_set_name (icon, "system-run-symbolic");
-			as_app_add_icon (AS_APP (app), icon);
 			as_app_add_category (AS_APP (app), "Addons");
 			as_app_add_category (AS_APP (app), "InputSources");
 		}
 
 		/* fix up codecs */
 		if (as_app_get_kind (AS_APP (app)) == AS_APP_KIND_CODEC) {
-			g_autoptr(AsIcon) icon = NULL;
-			icon = as_icon_new ();
-			as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
-			as_icon_set_name (icon, "application-x-addon");
-			as_app_add_icon (AS_APP (app), icon);
 			as_app_add_category (AS_APP (app), "Addons");
 			as_app_add_category (AS_APP (app), "Codecs");
 		}
 	}
 
 	/* success */
-	asb_app_set_hidpi_enabled (app, asb_context_get_flag (plugin->ctx,
-							      ASB_CONTEXT_FLAG_HIDPI_ICONS));
 	asb_plugin_add_app (apps, AS_APP (app));
 	return TRUE;
 }
