@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2017 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 /**
@@ -202,11 +188,15 @@ as_format_guess_kind (const gchar *filename)
 void
 as_format_set_filename (AsFormat *format, const gchar *filename)
 {
+	gchar *canon_filename;
+
 	AsFormatPrivate *priv = GET_PRIVATE (format);
 	g_return_if_fail (AS_IS_FORMAT (format));
 	if (priv->kind == AS_FORMAT_KIND_UNKNOWN)
 		priv->kind = as_format_guess_kind (filename);
-	as_ref_string_assign_safe (&priv->filename, filename);
+	canon_filename = g_canonicalize_filename (filename, NULL);
+	as_ref_string_assign_safe (&priv->filename, canon_filename);
+	g_free (canon_filename);
 }
 
 /**
