@@ -21,11 +21,14 @@
 #include <string.h>
 #include <archive_entry.h>
 #include <archive.h>
-#include <libsoup/soup.h>
 #include <stdlib.h>
 #ifndef _WIN32
+#ifdef __APPLE__
+#include <uuid/uuid.h>
+#else
 #include <uuid.h>
 #endif
+#endif
 
 #ifdef HAVE_RPM
 #include <rpm/rpmlib.h>
